@@ -14,6 +14,18 @@ test_that("Testing dissimilarity metrics on sparse data", {
         normalized = TRUE
     )
     expect_snapshot(cat(wunifrac_n))
+    expect_error(unifrac(
+        x = matrix_to_dtable(taxa$countData),
+        tree = taxa$treeData
+    ))
+    expect_error(unifrac(
+        x = taxa$countData,
+        tree = taxa$treeData,
+        threads = 1.2
+    ))
+    expect_error(unifrac(
+        x = taxa$countData
+    ))
 
     ## Testing Weighted UniFrac
     wunifrac <- unifrac(
@@ -39,6 +51,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(cos))
+    expect_no_error(cosine(x = taxa$countData, weighted = FALSE))
+    expect_error(cosine(x = taxa$countData, threads = 1.2))
+    expect_error(cosine(x = matrix_to_dtable(taxa$countData)))
 
     ## Testing Jaccard
     jac <- jaccard(
@@ -46,6 +61,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(jac))
+    expect_no_error(jaccard(x = taxa$countData, weighted = FALSE))
+    expect_error(jaccard(x = taxa$countData, threads = 1.2))
+    expect_error(jaccard(x = matrix_to_dtable(taxa$countData)))
 
     ## Testing Bray
     br <- bray(
@@ -53,6 +71,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(br))
+    expect_no_error(bray(x = taxa$countData, weighted = FALSE))
+    expect_error(bray(x = taxa$countData, threads = 1.2))
+    expect_error(bray(x = matrix_to_dtable(taxa$countData)))
 
     ## Testing Canberra
     can <- canberra(
@@ -60,6 +81,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(can))
+    expect_no_error(canberra(x = taxa$countData, weighted = FALSE))
+    expect_error(canberra(x = taxa$countData, threads = 1.2))
+    expect_error(canberra(x = matrix_to_dtable(taxa$countData)))
 
     ## Testing Jensen-Shannon Divergence
     jsd_res <- jsd(
@@ -67,6 +91,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(jsd_res))
+    expect_no_error(jsd(x = taxa$countData, weighted = FALSE))
+    expect_error(jsd(x = taxa$countData, threads = 1.2))
+    expect_error(jsd(x = matrix_to_dtable(taxa$countData)))
 
     ## Testing Manhattan
     man <- manhattan(
@@ -74,6 +101,9 @@ test_that("Testing dissimilarity metrics on sparse data", {
         weighted = TRUE
     )
     expect_snapshot(cat(man))
+    expect_no_error(manhattan(x = taxa$countData, weighted = FALSE))
+    expect_error(manhattan(x = taxa$countData, threads = 1.2))
+    expect_error(manhattan(x = matrix_to_dtable(taxa$countData)))
     }
 )
 
